Index: /extensions/Piwecard/css/index.php
===================================================================
--- /extensions/Piwecard/css/index.php	(revision 19924)
+++ /extensions/Piwecard/css/index.php	(revision 19924)
@@ -0,0 +1,33 @@
+<?php
+// +-----------------------------------------------------------------------+
+// | PhpWebGallery - a PHP based picture gallery                           |
+// | Copyright (C) 2002-2003 Pierrick LE GALL - pierrick@phpwebgallery.net |
+// | Copyright (C) 2003-2007 PhpWebGallery Team - http://phpwebgallery.net |
+// +-----------------------------------------------------------------------+
+// | file          : $Id: index.php 1912 2007-03-16 06:30:07Z rub $
+// | last update   : $Date: 2007-03-16 07:30:07 +0100 (ven, 16 mar 2007) $
+// | last modifier : $Author: rub $
+// | revision      : $Revision: 1912 $
+// +-----------------------------------------------------------------------+
+// | This program is free software; you can redistribute it and/or modify  |
+// | it under the terms of the GNU General Public License as published by  |
+// | the Free Software Foundation                                          |
+// |                                                                       |
+// | This program is distributed in the hope that it will be useful, but   |
+// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
+// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
+// | General Public License for more details.                              |
+// |                                                                       |
+// | You should have received a copy of the GNU General Public License     |
+// | along with this program; if not, write to the Free Software           |
+// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
+// | USA.                                                                  |
+// +-----------------------------------------------------------------------+
+
+// Recursive call
+$url = '../';
+header( 'Request-URI: '.$url );
+header( 'Content-Location: '.$url );
+header( 'Location: '.$url );
+exit();
+?>
Index: /extensions/Piwecard/css/piwecard.css
===================================================================
--- /extensions/Piwecard/css/piwecard.css	(revision 19923)
+++ /extensions/Piwecard/css/piwecard.css	(revision 19924)
@@ -57,4 +57,5 @@
 	color: #ff0000;
 	font-weight: bold;
+	display: none;
 }
 
Index: /extensions/Piwecard/include/config_param.inc.php
===================================================================
--- /extensions/Piwecard/include/config_param.inc.php	(revision 19923)
+++ /extensions/Piwecard/include/config_param.inc.php	(revision 19924)
@@ -1,4 +1,3 @@
 <?php
-
 global $conf;
 set_make_full_url();
@@ -6,18 +5,17 @@
 // Fichier contenant les parametres du plugin (pour le parser)
 $ecard_parse = array(
-		'%votrenom'		=> isset($_POST['votrenom']) ? $_POST['votrenom'] : ''  ,
-		'%votremail'	=> isset($_POST['votremail']) ? $_POST['votremail'] : ''  ,
-		'%sonnom'		=> isset($_POST['sonnom']) ? $_POST['sonnom'] : ''  ,
-		'%sonmail'		=> isset($_POST['sonmail']) ? $_POST['sonmail'] : ''  ,
-		'%site'			=> isset($conf['gallery_title']) ? $conf['gallery_title'] : '' ,
-		'%linksite'		=> get_absolute_root_url() ,
-		'%chemin'		=> isset($image_element['chemin']) ? $image_element['chemin'] : ''  ,
-		'%sujet'		=> isset($_POST['sujet']) ? $_POST['sujet'] : ''  ,
-		'%message'		=> isset($_POST['message']) ? $_POST['message'] : ''  ,	
-		'%imgurl'		=> DerivativeImage::thumb_url($image_element) ,
-		'%imginfos'		=> isset($image_element['imginfos']) ? $image_element['imginfos'] : ''  ,
+		'%yourname%'		=> isset($_POST['ecard_sender_name']) ? $_POST['ecard_sender_name'] : ''  ,
+		'%youremail%'		=> isset($_POST['ecard_sender_email']) ? $_POST['ecard_sender_email'] : ''  ,
+		'%recipientname%'	=> isset($_POST['ecard_recipient_name']) ? $_POST['ecard_recipient_name'] : ''  ,
+		'%recipientemail%'	=> isset($_POST['ecard_recipient_email']) ? $_POST['ecard_recipient_email'] : ''  ,
+		'%website%'			=> isset($conf['gallery_title']) ? $conf['gallery_title'] : '' ,
+		'%websiteurl%'		=> get_absolute_root_url() ,
+		'%ecardurl%'		=> isset($image_element['ecard_url']) ? $image_element['ecard_url'] : ''  ,
+		'%ecardsubject%'	=> isset($_POST['ecard_subject']) ? $_POST['ecard_subject'] : ''  ,
+		'%ecardmessage%'	=> isset($_POST['ecard_message']) ? $_POST['ecard_message'] : ''  ,	
+		'%pictureurl%'		=> DerivativeImage::thumb_url($image_element) ,
+		'%pictureinfos%'		=> isset($image_element['picture_infos']) ? $image_element['picture_infos'] : ''  ,
 		);
 
 unset_make_full_url();
-				
 ?>
Index: /extensions/Piwecard/include/ecard.class.php
===================================================================
--- /extensions/Piwecard/include/ecard.class.php	(revision 19923)
+++ /extensions/Piwecard/include/ecard.class.php	(revision 19924)
@@ -414,7 +414,7 @@
 					if ($this->my_config['ecard_showinfos']) {
 						if (isset($image_element['name'])) {
-							$image_element['imginfos'] = $image_element['name'];
+							$image_element['picture_infos'] = $image_element['name'];
 							if (isset($image_element['author']))
-								$image_element['imginfos'] .= ' ('.$image_element['author'].')';
+								$image_element['picture_infos'] .= ' ('.$image_element['author'].')';
 						}
 					}
@@ -437,6 +437,6 @@
 					// Complete the image_element array with Link for the ecard url to be added in the mail
 					set_make_full_url();
-					$mail_url = embellish_url(get_absolute_root_url() . './index.php?/ecard/'.$image_element['next_element_id']);
-					$image_element['mail_url'] = $mail_url;
+					$ecard_url = embellish_url(get_absolute_root_url() . './index.php?/ecard/'.$image_element['next_element_id']);
+					$image_element['ecard_url'] = $ecard_url;
 					unset_make_full_url();
 
Index: /extensions/Piwecard/language/da_DK/plugin.lang.php
===================================================================
--- /extensions/Piwecard/language/da_DK/plugin.lang.php	(revision 19923)
+++ /extensions/Piwecard/language/da_DK/plugin.lang.php	(revision 19924)
@@ -84,14 +84,14 @@
 $lang['ecard_manage'] = 'Parametre til denne funktion i galleri';
 $lang['ecard_parameters'] = '<b><u>Parametre</u></b>:<br> 
-<b>%votrenom</b>    ==> Afsenders navn<br>
-<b>%votremail</b>   ==> Afsenders mailadresse<br>
-<b>%sonnom</b>      ==> Modtagers navn<br>
-<b>%sonmail</b>     ==> Modtagers mailadresse<br>
-<b>%site</b>        ==> Websteds navn (Piwigos standardopsætning)<br>
-<b>%linksite</b>    ==> Websteds link (Piwigos standardopsætning)<br>
-<b>%chemin</b>      ==> Link til eCard-side<br>
-<b>%sujet</b>       ==> eCard-emne (skrives af brugeren)<br>
-<b>%message</b>     ==> eCard-meddelelse (skrives af brugeren)<br>
-<b>%imgurl</b>      ==> Link til fotografi<br>
-<b>%imginfos</b>    ==> Fotografioplysninger (navn og forfatter)';
+<b>%yourname%</b>    ==> Afsenders navn<br>
+<b>%youremail%</b>   ==> Afsenders mailadresse<br>
+<b>%recipientname%</b>      ==> Modtagers navn<br>
+<b>%recipientemail%</b>     ==> Modtagers mailadresse<br>
+<b>%website%</b>        ==> Websteds navn (Piwigos standardopsætning)<br>
+<b>%websiteurl%</b>    ==> Websteds link (Piwigos standardopsætning)<br>
+<b>%ecardurl%</b>      ==> Link til eCard-side<br>
+<b>%ecardsubject%</b>       ==> eCard-emne (skrives af brugeren)<br>
+<b>%ecardmessage%</b>     ==> eCard-meddelelse (skrives af brugeren)<br>
+<b>%pictureurl%</b>      ==> Link til fotografi<br>
+<b>%pictureinfos%</b>    ==> Fotografioplysninger (navn og forfatter)';
 ?>
Index: /extensions/Piwecard/language/de_DE/plugin.lang.php
===================================================================
--- /extensions/Piwecard/language/de_DE/plugin.lang.php	(revision 19923)
+++ /extensions/Piwecard/language/de_DE/plugin.lang.php	(revision 19924)
@@ -78,15 +78,15 @@
 $lang['ecard_parameters']      = 
 '<b><u>Einstellungen </u></b>:<br> 
-<b>%votrenom</b>    ==> Name des Absenders<br>
-<b>%votremail</b>   ==> Email des Absenders<br>
-<b>%sonnom</b>      ==> Name des Empfängers<br>
-<b>%sonmail</b>     ==> Email des Empfängers<br>
-<b>%site</b>        ==> Name der Webseite (Einstellung über Piwigo)<br>
-<b>%linksite</b>    ==> Link zur Webseite (Einstellung über Piwigo)<br>
-<b>%chemin</b>      ==> Link zur Seite Piwecard<br>
-<b>%sujet</b>       ==> Betreff der Email(vom Benutzer einzugeben)<br>
-<b>%message</b>     ==> Mitteilung der E-Card (vom Benutzer einzugeben)<br>
-<b>%imgurl</b>      ==> Link zum Bild<br>
-<b>%imginfos</b>    ==> Informationen über das Bild (Name und Autor)';
+<b>%yourname%</b>    ==> Name des Absenders<br>
+<b>%youremail%</b>   ==> Email des Absenders<br>
+<b>%recipientname%</b>      ==> Name des Empfängers<br>
+<b>%recipientemail%</b>     ==> Email des Empfängers<br>
+<b>%website%</b>        ==> Name der Webseite (Einstellung über Piwigo)<br>
+<b>%websiteurl%</b>    ==> Link zur Webseite (Einstellung über Piwigo)<br>
+<b>%ecardurl%</b>      ==> Link zur Seite Piwecard<br>
+<b>%ecardsubject%</b>       ==> Betreff der Email(vom Benutzer einzugeben)<br>
+<b>%ecardmessage%</b>     ==> Mitteilung der E-Card (vom Benutzer einzugeben)<br>
+<b>%pictureurl%</b>      ==> Link zum Bild<br>
+<b>%pictureinfos%</b>    ==> Informationen über das Bild (Name und Autor)';
 
 $lang['ecard_admin_consult']          = 'Liste';
Index: /extensions/Piwecard/language/el_GR/plugin.lang.php
===================================================================
--- /extensions/Piwecard/language/el_GR/plugin.lang.php	(revision 19923)
+++ /extensions/Piwecard/language/el_GR/plugin.lang.php	(revision 19924)
@@ -22,15 +22,15 @@
 // +-----------------------------------------------------------------------+
 $lang['ecard_parameters'] = '<b><u>Παράμετροι </u></b>:<br> 
-<b>%votrenom</b>    ==> Όνομα Αποστολέα<br>
-<b>%votremail</b>   ==> Διεύθυνση e-mail αποστολέα<br>
-<b>%sonnom</b>      ==> Όνομα Παραλήπτη<br>
-<b>%sonmail</b>     ==> Παραλήπτης Mail<br>
-<b>%site</b>        ==> Όνομα Ιστοσελίδας (πρότυπο διαμόρφωσης από το Piwigo)<br>
-<b>%linksite</b>    ==> Σύνδεσμος Ιστοσελίδας (πρότυπο διαμόρφωσης από το Piwigo)<br>
-<b>%chemin</b>      ==> Σύνδεσμος της σελίδας του eCard <br>
-<b>%sujet</b>       ==> Θέμα eCard (γράφεται από το χρήστη)<br>
-<b>%message</b>     ==> Μήνυμα eCard (γράφεται από το χρήστη) <br>
-<b>%imgurl</b>      ==> Σύνδεση με φωτογραφία <br>
-<b>%imginfos</b>    ==> Πληροφορίες Φωτογραφίας (όνομα και δημιουργός) 
+<b>%yourname%</b>    ==> Όνομα Αποστολέα<br>
+<b>%youremail%</b>   ==> Διεύθυνση e-mail αποστολέα<br>
+<b>%recipientname%</b>      ==> Όνομα Παραλήπτη<br>
+<b>%recipientemail%</b>     ==> Παραλήπτης Mail<br>
+<b>%website%</b>        ==> Όνομα Ιστοσελίδας (πρότυπο διαμόρφωσης από το Piwigo)<br>
+<b>%websiteurl%</b>    ==> Σύνδεσμος Ιστοσελίδας (πρότυπο διαμόρφωσης από το Piwigo)<br>
+<b>%ecardurl%</b>      ==> Σύνδεσμος της σελίδας του eCard <br>
+<b>%ecardsubject%</b>       ==> Θέμα eCard (γράφεται από το χρήστη)<br>
+<b>%ecardmessage%</b>     ==> Μήνυμα eCard (γράφεται από το χρήστη) <br>
+<b>%pictureurl%</b>      ==> Σύνδεση με φωτογραφία <br>
+<b>%pictureinfos%</b>    ==> Πληροφορίες Φωτογραφίας (όνομα και δημιουργός) 
 
 ';
Index: /extensions/Piwecard/language/en_UK/plugin.lang.php
===================================================================
--- /extensions/Piwecard/language/en_UK/plugin.lang.php	(revision 19923)
+++ /extensions/Piwecard/language/en_UK/plugin.lang.php	(revision 19924)
@@ -81,15 +81,15 @@
 $lang['ecard_message_html']				= 'Message sent (mail HTML with photo)';
 $lang['ecard_parameters'] = '<b><u>Parameters</u></b>:<br> 
-<b>%votrenom</b>    ==> Sender name<br>
-<b>%votremail</b>   ==> Sender mail<br>
-<b>%sonnom</b>      ==> Receiver name<br>
-<b>%sonmail</b>     ==> Receiver mail<br>
-<b>%site</b>        ==> Site name (Piwigo standard config)<br>
-<b>%linksite</b>    ==> Site link (Piwigo standard config)<br>
-<b>%chemin</b>      ==> Link to eCard page<br>
-<b>%sujet</b>       ==> eCard subject (write by user)<br>
-<b>%message</b>     ==> eCard message (write by user)<br>
-<b>%imgurl</b>      ==> Link to photo<br>
-<b>%imginfos</b>    ==> Photo information (name and author)';
+<b>%yourname%</b>    ==> Sender name<br>
+<b>%youremail%</b>   ==> Sender mail<br>
+<b>%recipientname%</b>      ==> Receiver name<br>
+<b>%recipientemail%</b>     ==> Receiver mail<br>
+<b>%website%</b>        ==> Site name (Piwigo standard config)<br>
+<b>%websiteurl%</b>    ==> Site link (Piwigo standard config)<br>
+<b>%ecardurl%</b>      ==> Link to eCard page<br>
+<b>%ecardsubject%</b>       ==> eCard subject (write by user)<br>
+<b>%ecardmessage%</b>     ==> eCard message (write by user)<br>
+<b>%pictureurl%</b>      ==> Link to photo<br>
+<b>%pictureinfos%</b>    ==> Photo information (name and author)';
 
 $lang['ecard_admin_consult']					= 'List';
Index: /extensions/Piwecard/language/es_ES/plugin.lang.php
===================================================================
--- /extensions/Piwecard/language/es_ES/plugin.lang.php	(revision 19923)
+++ /extensions/Piwecard/language/es_ES/plugin.lang.php	(revision 19924)
@@ -68,8 +68,8 @@
 <b>%enlacesitio</b>    ==> Enlace del sitio (Piwigo configuración estándar)<br>
 <b>%camino</b>      ==> enlace a la pagina de la tarjeta<br>
-<b>%sujeto</b>       ==> Asunto tarjeta electrónica (escribir por el usuario)<br>
+<b>%ecardsubject%o</b>       ==> Asunto tarjeta electrónica (escribir por el usuario)<br>
 <b>%mensaje</b>     ==> Mensaje de tarjeta electrónica (escribir por el usuario)<br>
-<b>%imgurl</b>      ==> Enlace a la foto<br>
-<b>%imginfos</b>    ==> Informaciones Foto (nombre y autor)';
+<b>%pictureurl%</b>      ==> Enlace a la foto<br>
+<b>%pictureinfos%</b>    ==> Informaciones Foto (nombre y autor)';
 $lang['ecard_publish_bottom'] = 'Esta postal fue enviada por';
 $lang['ecard_recursiv'] = 'Activar recursividad';
Index: /extensions/Piwecard/language/fr_FR/plugin.lang.php
===================================================================
--- /extensions/Piwecard/language/fr_FR/plugin.lang.php	(revision 19923)
+++ /extensions/Piwecard/language/fr_FR/plugin.lang.php	(revision 19924)
@@ -84,24 +84,24 @@
 $lang['ecard_parameters']			= 
 '<b><u>Paramètres </u></b>:<br> 
-<b>%votrenom</b>    ==> Nom de l\'expéditeur<br>
-<b>%votremail</b>   ==> Mail de l\'expéditeur<br>
-<b>%sonnom</b>      ==> Nom du destinataire<br>
-<b>%sonmail</b>     ==> Mail du destinataire<br>
-<b>%site</b>        ==> Nom du site (paramètre config piwigo)<br>
-<b>%linksite</b>    ==> Lien vers le site (paramètre config piwigo)<br>
-<b>%chemin</b>      ==> Lien vers la page Piwecard<br>
-<b>%sujet</b>       ==> sujet de la carte (saisi par l\'utilisateur)<br>
-<b>%message</b>     ==> Message de la carte (saisi par l\'utilisateur)<br>
-<b>%imgurl</b>      ==> Lien vers l\'image<br>
-<b>%imginfos</b>    ==> Informations de l\'image (nom et auteur)';
+<b>%yourname%</b>    ==> Nom de l\'expéditeur<br>
+<b>%youremail%</b>   ==> Mail de l\'expéditeur<br>
+<b>%recipientname%</b>      ==> Nom du destinataire<br>
+<b>%recipientemail%</b>     ==> Mail du destinataire<br>
+<b>%website%</b>        ==> Nom du site (paramètre config piwigo)<br>
+<b>%websiteurl%</b>    ==> Lien vers le site (paramètre config piwigo)<br>
+<b>%ecardurl%</b>      ==> Lien vers la page Piwecard<br>
+<b>%ecardsubject%</b>       ==> sujet de la carte (saisi par l\'utilisateur)<br>
+<b>%ecardmessage%</b>     ==> Message de la carte (saisi par l\'utilisateur)<br>
+<b>%pictureurl%</b>      ==> Lien vers l\'image<br>
+<b>%pictureinfos%</b>    ==> Informations de l\'image (nom et auteur)';
 
 $lang['ecard_admin_consult']					= 'Consultation';
 $lang['ecard_consult_detail']			= 'Consultation des eCard présentes';
 $lang['ecard_list']						= 'Liste des Cartes Virtuelles envoyées';
-$lang['ecard_delete_all']				= 'Effacer toutes les cartes périmées?';
+$lang['ecard_delete_all']				= 'Effacer toutes les cartes périmées ?';
 $lang['valid']							= 'Valide(s)';
 $lang['total']							= 'Total';
-$lang['ecard_force_delete']				= 'Effacer (forcer) la carte?';
-$lang['ecard_delete']					= 'Effacer la carte?';
+$lang['ecard_force_delete']				= 'Effacer (forcer) la carte ?';
+$lang['ecard_delete']					= 'Effacer la carte ?';
 
 $lang['ecard_admin_submit']				= 'Enregistrer';
Index: /extensions/Piwecard/language/hu_HU/plugin.lang.php
===================================================================
--- /extensions/Piwecard/language/hu_HU/plugin.lang.php	(revision 19923)
+++ /extensions/Piwecard/language/hu_HU/plugin.lang.php	(revision 19924)
@@ -48,15 +48,15 @@
 $lang['ecard_send_dest'] = 'Címzett';
 $lang['ecard_parameters'] = '<b><u>Paraméterek </u></b>:<br> 
-<b>%votrenom</b>    ==> Feladó neve<br>
-<b>%votremail</b>   ==> Feladó E-mail címe<br>
-<b>%sonnom</b>      ==> Címzett neve<br>
-<b>%sonmail</b>     ==> Címzett E-mail címe<br>
-<b>%site</b>        ==> Honlap neve (Piwigo alapértelmezett beállítás)<br>
-<b>%linksite</b>    ==> Honlap elérési útja (Piwigo alapértelmezett beállítás)<br>
-<b>%chemin</b>      ==> E-képeslap oldal elérési útja<br>
-<b>%sujet</b>       ==> E-képeslap tárgya (felhasználó által szerkesztett)<br>
-<b>%message</b>     ==> E-képeslap üzenet (felhasználó által szerkesztett)<br>
-<b>%imgurl</b>      ==> Kép elérési útja<br>
-<b>%imginfos</b>    ==> Kép információk (név és szerző)';
+<b>%yourname%</b>    ==> Feladó neve<br>
+<b>%youremail%</b>   ==> Feladó E-mail címe<br>
+<b>%recipientname%</b>      ==> Címzett neve<br>
+<b>%recipientemail%</b>     ==> Címzett E-mail címe<br>
+<b>%website%</b>        ==> Honlap neve (Piwigo alapértelmezett beállítás)<br>
+<b>%websiteurl%</b>    ==> Honlap elérési útja (Piwigo alapértelmezett beállítás)<br>
+<b>%ecardurl%</b>      ==> E-képeslap oldal elérési útja<br>
+<b>%ecardsubject%</b>       ==> E-képeslap tárgya (felhasználó által szerkesztett)<br>
+<b>%ecardmessage%</b>     ==> E-képeslap üzenet (felhasználó által szerkesztett)<br>
+<b>%pictureurl%</b>      ==> Kép elérési útja<br>
+<b>%pictureinfos%</b>    ==> Kép információk (név és szerző)';
 $lang['ecard_delete'] = 'Töröljük az e-képeslapot?';
 $lang['ecard_delete_all'] = 'Töröljük az összes lejárt e-képeslapot?';
Index: /extensions/Piwecard/language/it_IT/plugin.lang.php
===================================================================
--- /extensions/Piwecard/language/it_IT/plugin.lang.php	(revision 19923)
+++ /extensions/Piwecard/language/it_IT/plugin.lang.php	(revision 19924)
@@ -78,15 +78,15 @@
 $lang['ecard_parameters']			= 
 '<b><u>Impostazioni </u></b>:<br> 
-<b>%votrenom</b>    ==> Nome del mittente<br>
-<b>%votremail</b>   ==> Email del mittente<br>
-<b>%sonnom</b>      ==> Nome del destinatario<br>
-<b>%sonmail</b>     ==> Email del destinatario<br>
-<b>%site</b>        ==> Nome del sito (impostazione di config Piwigo)<br>
-<b>%linksite</b>    ==> Link del sito (impostazione config Piwigo)<br>
-<b>%chemin</b>      ==> Link verso la pagina Piwecard<br>
-<b>%sujet</b>       ==> soggetto della cartolina (inserita dall\'utente)<br>
-<b>%message</b>     ==> Messaggio della cartolina (inserita dall\'utente)<br>
-<b>%imgurl</b>      ==> Link verso la foto<br>
-<b>%imginfos</b>    ==> Informazioni della foto (nome e autore)';
+<b>%yourname%</b>    ==> Nome del mittente<br>
+<b>%youremail%</b>   ==> Email del mittente<br>
+<b>%recipientname%</b>      ==> Nome del destinatario<br>
+<b>%recipientemail%</b>     ==> Email del destinatario<br>
+<b>%website%</b>        ==> Nome del sito (impostazione di config Piwigo)<br>
+<b>%websiteurl%</b>    ==> Link del sito (impostazione config Piwigo)<br>
+<b>%ecardurl%</b>      ==> Link verso la pagina Piwecard<br>
+<b>%ecardsubject%</b>       ==> soggetto della cartolina (inserita dall\'utente)<br>
+<b>%ecardmessage%</b>     ==> Messaggio della cartolina (inserita dall\'utente)<br>
+<b>%pictureurl%</b>      ==> Link verso la foto<br>
+<b>%pictureinfos%</b>    ==> Informazioni della foto (nome e autore)';
 
 $lang['ecard_admin_consult']					= 'Consultazione';
Index: /extensions/Piwecard/language/lv_LV/plugin.lang.php
===================================================================
--- /extensions/Piwecard/language/lv_LV/plugin.lang.php	(revision 19923)
+++ /extensions/Piwecard/language/lv_LV/plugin.lang.php	(revision 19924)
@@ -78,15 +78,15 @@
 $lang['ecard_parameters'] ='
 <b><u>Parametri</u></b> :<br>
-<b>%votrenom</b> ==> Sūtītāja vārds<br>
-<b>%votremail</b> ==> Sūtītāja Vēstule<br>
-<b>%sonnom</b> ==> Saņēmēja Vārds<br>
-<b>%sonmail</b> ==> Saņēmēja Vēstule<br>
-<b>%site</b> ==> Vietnes Nosaukums (Piwigo standarta konfigurācija)<br>
-<b>%linksite</b> ==> Vietnes saite (Piwigo standarta konfigurācija)<br>
-<b>%chemin</b> ==> Saite uz eKartes lapu<br>
-<b>%sujet</b> ==> eKartes Tēma (lietotāja rakstīta)<br>
-<b>%message</b> ==> eKartes Ziņa (lietotāja rakstīta)<br>
-<b>%imgurl</b> ==> Saite uz foto<br>
-<b>%imginfos</b> ==> Informācija par Foto (nosaukums un autors)';
+<b>%yourname%</b> ==> Sūtītāja vārds<br>
+<b>%youremail%</b> ==> Sūtītāja Vēstule<br>
+<b>%recipientname%</b> ==> Saņēmēja Vārds<br>
+<b>%recipientemail%</b> ==> Saņēmēja Vēstule<br>
+<b>%website%</b> ==> Vietnes Nosaukums (Piwigo standarta konfigurācija)<br>
+<b>%websiteurl%</b> ==> Vietnes saite (Piwigo standarta konfigurācija)<br>
+<b>%ecardurl%</b> ==> Saite uz eKartes lapu<br>
+<b>%ecardsubject%</b> ==> eKartes Tēma (lietotāja rakstīta)<br>
+<b>%ecardmessage%</b> ==> eKartes Ziņa (lietotāja rakstīta)<br>
+<b>%pictureurl%</b> ==> Saite uz foto<br>
+<b>%pictureinfos%</b> ==> Informācija par Foto (nosaukums un autors)';
 
 $lang['ecard_admin_consult'] = 'Saraksts';
Index: /extensions/Piwecard/language/ru_RU/plugin.lang.php
===================================================================
--- /extensions/Piwecard/language/ru_RU/plugin.lang.php	(revision 19923)
+++ /extensions/Piwecard/language/ru_RU/plugin.lang.php	(revision 19924)
@@ -78,15 +78,15 @@
 $lang['ecard_parameters']            =
 '<b><u>Paramètres </u></b>:<br>
-<b>%votrenom</b>    ==> Имя оправителя<br>
-<b>%votremail</b>   ==> Почта отправителя<br>
-<b>%sonnom</b>      ==> Имя получателя<br>
-<b>%sonmail</b>     ==> Почта получателя<br>
-<b>%site</b>        ==> Название сайта (стандартная конфигурация Piwigo)<br>
-<b>%linksite</b>    ==> Ссылка на сайт (стандартная конфигурация Piwigo)<br>
-<b>%chemin</b>      ==> Ссылка на страницу хранения открытки<br>
-<b>%sujet</b>       ==> Тема открытки (заполняется пользователем)<br>
-<b>%message</b>     ==> Сообщение открытки (заполняется пользователем)<br>
-<b>%imgurl</b>      ==> Ссылка на фотографию<br>
-<b>%imginfos</b>    ==> Информация о фотографии (название и автор)';
+<b>%yourname%</b>    ==> Имя оправителя<br>
+<b>%youremail%</b>   ==> Почта отправителя<br>
+<b>%recipientname%</b>      ==> Имя получателя<br>
+<b>%recipientemail%</b>     ==> Почта получателя<br>
+<b>%website%</b>        ==> Название сайта (стандартная конфигурация Piwigo)<br>
+<b>%websiteurl%</b>    ==> Ссылка на сайт (стандартная конфигурация Piwigo)<br>
+<b>%ecardurl%</b>      ==> Ссылка на страницу хранения открытки<br>
+<b>%ecardsubject%</b>       ==> Тема открытки (заполняется пользователем)<br>
+<b>%ecardmessage%</b>     ==> Сообщение открытки (заполняется пользователем)<br>
+<b>%pictureurl%</b>      ==> Ссылка на фотографию<br>
+<b>%pictureinfos%</b>    ==> Информация о фотографии (название и автор)';
 
 $lang['ecard_admin_consult']                    = 'Список';
Index: /extensions/Piwecard/language/sk_SK/plugin.lang.php
===================================================================
--- /extensions/Piwecard/language/sk_SK/plugin.lang.php	(revision 19923)
+++ /extensions/Piwecard/language/sk_SK/plugin.lang.php	(revision 19924)
@@ -78,15 +78,15 @@
 $lang['ecard_parameters']			= 
 '<b><u>Parametre </u></b>:<br> 
-<b>%votrenom</b>    ==> Meno odosielateľa<br>
-<b>%votremail</b>   ==> Mail odosielateľa<br>
-<b>%sonnom</b>      ==> Meno prijímateľa<br>
-<b>%sonmail</b>     ==> Mail prijímateľa<br>
-<b>%site</b>        ==> Meno stránky (Piwigo štandardná konfigurácia)<br>
-<b>%linksite</b>    ==> Link na stránku (Piwigo štandardná konfigurácia)<br>
-<b>%chemin</b>      ==> Link na stránku ePohľadnice<br>
-<b>%sujet</b>       ==> Predmet ePohľadnice (napísané používateľom)<br>
-<b>%message</b>     ==> Správa ePohľadnice (napísané používateľom)<br>
-<b>%imgurl</b>      ==> Link na fotku<br>
-<b>%imginfos</b>    ==> Informácie o fotke (názov a autor)';
+<b>%yourname%</b>    ==> Meno odosielateľa<br>
+<b>%youremail%</b>   ==> Mail odosielateľa<br>
+<b>%recipientname%</b>      ==> Meno prijímateľa<br>
+<b>%recipientemail%</b>     ==> Mail prijímateľa<br>
+<b>%website%</b>        ==> Meno stránky (Piwigo štandardná konfigurácia)<br>
+<b>%websiteurl%</b>    ==> Link na stránku (Piwigo štandardná konfigurácia)<br>
+<b>%ecardurl%</b>      ==> Link na stránku ePohľadnice<br>
+<b>%ecardsubject%</b>       ==> Predmet ePohľadnice (napísané používateľom)<br>
+<b>%ecardmessage%</b>     ==> Správa ePohľadnice (napísané používateľom)<br>
+<b>%pictureurl%</b>      ==> Link na fotku<br>
+<b>%pictureinfos%</b>    ==> Informácie o fotke (názov a autor)';
 
 $lang['ecard_admin_consult']					= 'Zoznam';
Index: /extensions/Piwecard/language/sv_SE/plugin.lang.php
===================================================================
--- /extensions/Piwecard/language/sv_SE/plugin.lang.php	(revision 19923)
+++ /extensions/Piwecard/language/sv_SE/plugin.lang.php	(revision 19924)
@@ -78,15 +78,15 @@
 $lang['ecard_parameters']            =
 '<b><u>Paramètres </u></b>:<br>
-<b>%votrenom</b>    ==> Sender name<br>
-<b>%votremail</b>   ==> Sender Mail<br>
-<b>%sonnom</b>      ==> Receiver Name<br>
-<b>%sonmail</b>     ==> Receiver Mail<br>
-<b>%site</b>        ==> Site Name (Piwigo standard config)<br>
-<b>%linksite</b>    ==> Site link (Piwigo standard config)<br>
-<b>%chemin</b>      ==> Link to eCard page<br>
-<b>%sujet</b>       ==> eCard Subject (write by user)<br>
-<b>%message</b>     ==> eCard Message (write by user)<br>
-<b>%imgurl</b>      ==> Link to photo<br>
-<b>%imginfos</b>    ==> Photo Informations (name and author)';
+<b>%yourname%</b>    ==> Sender name<br>
+<b>%youremail%</b>   ==> Sender Mail<br>
+<b>%recipientname%</b>      ==> Receiver Name<br>
+<b>%recipientemail%</b>     ==> Receiver Mail<br>
+<b>%website%</b>        ==> Site Name (Piwigo standard config)<br>
+<b>%websiteurl%</b>    ==> Site link (Piwigo standard config)<br>
+<b>%ecardurl%</b>      ==> Link to eCard page<br>
+<b>%ecardsubject%</b>       ==> eCard Subject (write by user)<br>
+<b>%ecardmessage%</b>     ==> eCard Message (write by user)<br>
+<b>%pictureurl%</b>      ==> Link to photo<br>
+<b>%pictureinfos%</b>    ==> Photo Informations (name and author)';
 
 $lang['ecard_admin_consult']                    = 'Listningar';
Index: /extensions/Piwecard/template/ecard.tpl
===================================================================
--- /extensions/Piwecard/template/ecard.tpl	(revision 19923)
+++ /extensions/Piwecard/template/ecard.tpl	(revision 19924)
@@ -32,9 +32,9 @@
 		case TEXT:
 			if (element.value == '') {
-				document.getElementById(element.id+'_error').innerHTML = "{'ecard_error'|@translate} {'ecard_error_text'|@translate}";
+				document.getElementById(element.id+'_error').style.display = 'block';
 				element.className += " ecard_error_input";
 				return false;
 			} else {
-				document.getElementById(element.id+'_error').innerHTML = '';
+				document.getElementById(element.id+'_error').style.display = 'none';
 				element.className = element.className.replace( /(?:^|\s)ecard_error_input(?!\S)/g , '');
 				return true;
@@ -44,9 +44,9 @@
 			var filter = /^([a-zA-Z0-9_\.\-])+\@(([a-zA-Z0-9\-])+\.)+([a-zA-Z0-9]{2,4})+$/;
 			if (!filter.test(element.value)) {
-				document.getElementById(element.id+'_error').innerHTML = "{'ecard_error'|@translate} {'ecard_error_email'|@translate}";
+				document.getElementById(element.id+'_error').style.display = 'block';
 				element.className += " ecard_error_input";
 				return false;
 			} else {
-				document.getElementById(element.id+'_error').innerHTML = '';
+				document.getElementById(element.id+'_error').style.display = 'none';
 				element.className = element.className.replace( /(?:^|\s)ecard_error_input(?!\S)/g , '');
 				return true;
@@ -80,6 +80,6 @@
 				<legend>{'ecard_send_stage1'|@translate}</legend>
 				<div class="ecard_field">
-					<div class="ecard_error" id="ecard_subject_error"></div>
-					<div class="ecard_error" id="ecard_message_error"></div>
+					<div class="ecard_error" id="ecard_subject_error">{'ecard_error'|@translate} {'ecard_error_text'|@translate}</div>
+					<div class="ecard_error" id="ecard_message_error">{'ecard_error'|@translate} {'ecard_error_text'|@translate}</div>
 					<span class="ecard_label">{'ecard_send_title'|@translate}<span class="ecard_mandatory_fields">*</span> :</span>
 					<span class="ecard_input_right"><input name="ecard_subject" type="text" id="ecard_subject" value="{$ecard.subject}" onfocus="ecard_clearDefaultText(this, '{$ecard.subject}');" title="{$ecard.subject}"></span>
@@ -93,6 +93,6 @@
 				<legend>{'ecard_send_stage2'|@translate}</legend>
 				<div class="ecard_field">
-					<div class="ecard_error" id="ecard_sender_name_error"></div>
-					<div class="ecard_error" id="ecard_sender_email_error"></div>
+					<div class="ecard_error" id="ecard_sender_name_error">{'ecard_error'|@translate} {'ecard_error_text'|@translate}</div>
+					<div class="ecard_error" id="ecard_sender_email_error">{'ecard_error'|@translate} {'ecard_error_email'|@translate}</div>
 					<span class="ecard_label">{'ecard_send_exp'|@translate}<span class="ecard_mandatory_fields">*</span> :</span>
 					<span class="ecard_name"><input name="ecard_sender_name" type="text" id="ecard_sender_name" maxlength="100" value="{$ecard.sender_name}"></span>
@@ -100,6 +100,6 @@
 				</div>
 				<div class="ecard_field">
-					<div class="ecard_error" id="ecard_recipient_name_error"></div>
-					<div class="ecard_error" id="ecard_recipient_email_error"></div>
+					<div class="ecard_error" id="ecard_recipient_name_error">{'ecard_error'|@translate} {'ecard_error_text'|@translate}</div>
+					<div class="ecard_error" id="ecard_recipient_email_error">{'ecard_error'|@translate} {'ecard_error_email'|@translate}</div>
 					<span class="ecard_label">{'ecard_send_dest'|@translate}<span class="ecard_mandatory_fields">*</span> :</span>
 					<span class="ecard_name"><input name="ecard_recipient_name" type="text" id="ecard_recipient_name" maxlength="100" value="{$ecard.recipient_name}" onfocus="ecard_clearDefaultText(this, '{$ecard.recipient_name}');"></span>

Index: /extensions/Piwecard/include/default_values.inc.php
===================================================================
--- /extensions/Piwecard/include/default_values.inc.php	(revision 19923)
+++ /extensions/Piwecard/include/default_values.inc.php	(revision 19924)
@@ -1,8 +1,3 @@
 <?php
-/*
- * Plugin Name: Piwcard
- * File :  default_values.inc.php  
- */
-
 $ecard_default_values['site_name'] = ""; // Site Name
 $ecard_default_values['allcats'] = false;;	// active plugin on all categories
@@ -12,12 +7,12 @@
 
 // message for the mail when only a link is sent
-$ecard_default_values['message_link'] = "Bonjour %sonnom! 
-%votrenom vous a envoy&eacute; une eCard depuis le site %site. 
-Vous pouvez la consulter sur %chemin .
-	A bientot sur %site (%linksite) !
+$ecard_default_values['message_link'] = "Bonjour %recipientname%! 
+%yourname% vous a envoy&eacute; une eCard depuis le site %website%. 
+Vous pouvez la consulter sur %ecardurl%.
+	A bientot sur %website% (%websiteurl%) !
 	Le Webmaster";
 
 
-$ecard_default_values['subject_link'] = "Une eCard vous a ete envoyee par %votrenom"; // subject of the mail when only a link is sent
+$ecard_default_values['subject_link'] = "Une eCard vous a ete envoyee par %yourname%"; // subject of the mail when only a link is sent
 
 $ecard_default_values['groups'] = array(); // Groups
@@ -31,21 +26,20 @@
 
 $ecard_default_values['active_parameter'] = true;	// Add function for a user to choice the valid duration for an ecard
-$ecard_default_values['message_HTML'] = 'Bonjour %sonnom! 
-<b>%votrenom</b> vous a envoy&eacute; une eCard depuis le site <a href="%linksite">%site</a> :
+$ecard_default_values['message_HTML'] = 'Bonjour %recipientname%! 
+<b>%yourname%</b> vous a envoy&eacute; une eCard depuis le site <a href="%websiteurl%">%website%</a> :
 
-<b>%sujet<b>
-	<a href="%chemin"> 
-	<img class="theImage" src="%imgurl"/> 
+<b>%ecardsubject%<b>
+	<a href="%ecardurl%"> 
+	<img class="theImage" src="%pictureurl%"/> 
 	</a>
-	%imginfos
+	%pictureinfos%
 <p>
-%message
+%ecardmessage%
 <p>
-Vous pouvez &eacute;galement <a href="%chemin">en cliquant sur le lien ici</a> .
-	A bientot sur <a href="%linksite">%site</a> !
-	Le Webmaster';
+Vous pouvez &eacute;galement <a href="%ecardurl%">en cliquant sur le lien ici</a> .
+A bientot sur <a href="%websiteurl%">%website%</a> !
+Le Webmaster';
 
 $ecard_default_values['ecard_showinfos']	= false;	// Default : dont show infos under image in ecard
 $ecard_default_values['defaultmail']	    = '';	    // Default mail used for guest user
-
 ?>